<!---
Do not edit this file. This file rendered from templates/readme.md.
See Contributing for how to update this file.
--->
<p align="center">
<a href="https://pipxproject.github.io/pipx/">
<img align="center" src="https://github.com/pipxproject/pipx/raw/master/logo.png" height="200px"/>
</a>
</p>

<p align="center">
pipx: execute binaries from Python packages in isolated environments
</p>

**Documentation**: https://pipxproject.github.io/pipx/

**Source Code**: https://github.com/pipxproject/pipx


<p align="center">
<a href="https://travis-ci.org/pipxproject/pipx"><img src="https://travis-ci.org/pipxproject/pipx.svg?branch=master" /></a>

<a href="https://pypi.python.org/pypi/pipx/">
<img src="https://img.shields.io/badge/pypi-0.13.2.0b1-blue.svg" /></a>
<a href="https://github.com/ambv/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

---

<p align="center">
<a href="https://github.com/pipxproject/pipx/raw/master/pipx_demo.gif">
<img src="https://github.com/pipxproject/pipx/raw/master/pipx_demo.gif"/>
</a>
</p>

### Quick Installation Guide

In a hurry? Here's how to get started with pipx:

```
python3 -m pip install --user pipx
python3 -m pipx ensurepath
```

Now you can try things like `pipx run black --help`, `pipx install flake8`, or `pipx --help`.

For more details, see [installation](https://pipxproject.github.io/pipx/installation/).